{#def metadata, search_link #}
{% set metadata_dict = metadata | to_dict %}
{% set creators = metadata_dict['creators'] %}
{% set contributors = metadata_dict['contributors'] %}

<div class="ui double separated">
   <div role="list" class="ui horizontal separated creatibutors list">
            {% for person in creators %}
                <Person person={person} search_link={search_link} searchFacet="syntheticFields_people"></Person>
            {% endfor %}
    </div>
     {% if contributors %}
        <div class="double separator"></div>
            <div role="list" class="ui horizontal separated creatibutors list">

                {% for contributor in contributors%}
                  {% if contributor.contributorType.title %}
                    {% set role = contributor.contributorType.title %}
                  {% endif %}
                  <Person person={contributor} search_link={search_link} searchFacet="syntheticFields_people" role={role}></Person>

                {% endfor %}
            </div>
        {% endif %}

 </div>





