{# def pids #}
{% for pid in pids %}
<div class="item">

    <{{ 'a href={url} target="_blank"'.format(url=pid.url) if pid.url else 'span' }}  class="ui label green image">
        <i class="external alternate icon"></i>
        {{scheme}}
        <div class="detail">
            {{pid.identifier}}

        </div>
    </{{ 'a' if pid.url else 'span'}}>
</div>
{% endfor %}


